@@ -32,7 +32,14 @@ def cli(ctx):
         ctx.obj.service = ctx.obj.client.service("project")
 
 
-from nextcodecli.commands.project.fileaccess import list_bucket, upload, download, delete, head, credentials
+from nextcodecli.commands.project.fileaccess import (
+    list_bucket,
+    upload,
+    download,
+    delete,
+    head,
+    credentials,
+)
 from nextcodecli.commands.project.status import status, create, update, view
 from nextcodecli.commands.project.users import users
 
@@ -46,4 +53,4 @@ cli.add_command(users)
 cli.add_command(create)
 cli.add_command(update)
 cli.add_command(view)
-cli.add_command(credentials)
\ No newline at end of file
+cli.add_command(credentials)
